package cn.com.infosec.asn1;

import java.math.BigInteger;

public class DEREnumerated extends ASN1Object {
   byte[] bytes;

   public static DEREnumerated getInstance(Object obj) {
      if (obj != null && !(obj instanceof DEREnumerated)) {
         if (obj instanceof ASN1OctetString) {
            return new DEREnumerated(((ASN1OctetString)obj).getOctets());
         } else if (obj instanceof ASN1TaggedObject) {
            return getInstance(((ASN1TaggedObject)obj).getObject());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (DEREnumerated)obj;
      }
   }

   public static DEREnumerated getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   public DEREnumerated(int value) {
      this.bytes = BigInteger.valueOf((long)value).toByteArray();
   }

   public DEREnumerated(BigInteger value) {
      this.bytes = value.toByteArray();
   }

   public DEREnumerated(byte[] bytes) {
      this.bytes = bytes;
   }

   public BigInteger getValue() {
      return new BigInteger(this.bytes);
   }

   void encode(DEROutputStream out) {
      out.writeEncoded(10, this.bytes);
   }

   boolean asn1Equals(DERObject o) {
      if (!(o instanceof DEREnumerated)) {
         return false;
      } else {
         DEREnumerated o1 = (DEREnumerated)o;
         if (this.bytes.length != o1.bytes.length) {
            return false;
         } else {
            byte[] var3;
            for(int var2 = 0; var2 != (var3 = this.bytes).length; ++var2) {
               if (var3[var2] != o1.bytes[var2]) {
                  return false;
               }
            }

            return true;
         }
      }
   }

   public int hashCode() {
      return this.getValue().hashCode();
   }
}
